==> chat-customer-service-plugin-vue-1.0.2.tgz: package/utils/index.ts <==
import TIM, { Message } from 'tim-js-sdk/tim-js-friendship';
import { customerServicePayloadType } from './interface'
import { CUSTOM_MESSAGE_SRC } from './im';
// Determine if it is a JSON string
export function isJSON(str: string): boolean {
    // eslint-disable-next-line no-useless-escape
    if (
        /^[\],:{}\s]*$/.test(
            str
                // eslint-disable-next-line no-useless-escape
                .replace(/\\["\\\/bfnrtu]/g, '@')
                // eslint-disable-next-line no-useless-escape
                .replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']')
                .replace(/(?:^|:|,)(?:\s*\[)+/g, '')
        )
    ) {
        return true;
    }
    return false;
}

// Determine if it is a JSON string
export function JSONToObject(str: string) {
    if (!isJSON(str)) {
        return str;
    }
    return JSON.parse(str);
}



export function isCustomerServiceMessage(message: Message): boolean {
    const customerServicePayload: customerServicePayloadType = JSONToObject(message?.payload?.data)
    if (customerServicePayload.customerServicePlugin == 0) {
        return true
    }
    return false;
}

export const isMessageInvisible = (message: Message): boolean => {
    const customerServicePayload: customerServicePayloadType = JSONToObject(message?.payload?.data)
    try {
        const robotCommandArray = ['feedback', 'updateBotStatus']
        const whiteList = [
            CUSTOM_MESSAGE_SRC.MENU,
            CUSTOM_MESSAGE_SRC.BRANCH,
            CUSTOM_MESSAGE_SRC.FROM_INPUT,
            CUSTOM_MESSAGE_SRC.PRODUCT_CARD,
        ]
        if (
            (message?.type === TIM?.TYPES?.MSG_CUSTOM &&
                (!whiteList.includes(customerServicePayload.src)
                    || (customerServicePayload.src === CUSTOM_MESSAGE_SRC.ROBOT && robotCommandArray.indexOf(customerServicePayload?.content.command) !== -1))
            )
        ) {
            return true;
        }
        return false;
    } catch (e) {
        console.log(e);
        return false;
    }
};

export const isMessageRating = (message: Message): boolean => {
    const customerServicePayload: customerServicePayloadType = JSONToObject(message?.payload?.data)
    if (
        (message?.type === TIM?.TYPES?.MSG_CUSTOM && customerServicePayload.customerServicePlugin == 0 &&
            customerServicePayload.src === CUSTOM_MESSAGE_SRC.MENU)
    ) {
        return true;
    }
    return false;
};

export const isRenderMessage = (message: Message): boolean => {
    if (!message.isRevoked) {
        if (message?.type !== TIM?.TYPES?.MSG_CUSTOM) {
            return true
        }
        if (message?.type === TIM?.TYPES?.MSG_CUSTOM && isCustomerServiceMessage(message) && !isMessageInvisible(message)) {
            return true
        }
        if (message?.type === TIM?.TYPES?.MSG_CUSTOM && isCustomerServiceMessage(message) && isMessageInvisible(message)) {
            return false
        }
        if (message?.type === TIM?.TYPES?.MSG_CUSTOM && !isCustomerServiceMessage(message)) {
            return true
        }
    } else {
        return false;
    }
    return false;

}

==> chat-customer-service-plugin-vue2-1.0.0.tgz: package/utils/index.ts <==
import TUIChatEngine, { IMessageModel } from "@tencentcloud/chat-uikit-engine";
import { customerServicePayloadType } from './interface'
import { CUSTOM_MESSAGE_SRC } from './im';

// Determine if it is a JSON string
export function isJSON(str: string): boolean {
    // eslint-disable-next-line no-useless-escape
    if (
        /^[\],:{}\s]*$/.test(
            str
                // eslint-disable-next-line no-useless-escape
                .replace(/\\["\\\/bfnrtu]/g, '@')
                // eslint-disable-next-line no-useless-escape
                .replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']')
                .replace(/(?:^|:|,)(?:\s*\[)+/g, '')
        )
    ) {
        return true;
    }
    return false;
}

// Determine if it is a JSON string
export function JSONToObject(str: string) {
    if (!isJSON(str)) {
        return str;
    }
    return JSON.parse(str);
}



export function isCustomerServiceMessage(message: typeof IMessageModel): boolean {
    const customerServicePayload: customerServicePayloadType = JSONToObject(message?.payload?.data)
    if (customerServicePayload.customerServicePlugin == 0) {
        return true
    }
    return false;
}

export const isMessageInvisible = (message: typeof IMessageModel): boolean => {
    const customerServicePayload: customerServicePayloadType = JSONToObject(message?.payload?.data)
    try {
        const robotCommandArray = ['feedback', 'updateBotStatus']
        const whiteList = [
            CUSTOM_MESSAGE_SRC.MENU,
            CUSTOM_MESSAGE_SRC.BRANCH,
            CUSTOM_MESSAGE_SRC.FROM_INPUT,
            CUSTOM_MESSAGE_SRC.PRODUCT_CARD,
        ]
        if (
            (message?.type === TUIChatEngine.TYPES.MSG_CUSTOM &&
                (!whiteList.includes(customerServicePayload.src)
                    || (customerServicePayload.src === CUSTOM_MESSAGE_SRC.ROBOT && robotCommandArray.indexOf(customerServicePayload?.content.command) !== -1))
            )
        ) {
            return true;
        }
        return false;
    } catch (e) {
        console.log(e);
        return false;
    }
};

export const isMessageRating = (message: typeof IMessageModel): boolean => {
    const customerServicePayload: customerServicePayloadType = JSONToObject(message?.payload?.data)
    if (
        (message?.type === TUIChatEngine.TYPES.MSG_CUSTOM && customerServicePayload.customerServicePlugin == 0 &&
            customerServicePayload.src === CUSTOM_MESSAGE_SRC.MENU)
    ) {
        return true;
    }
    return false;
};

export const isRenderMessage = (message: typeof IMessageModel): boolean => {
    if (!message.isRevoked) {
        if (message?.type !== TUIChatEngine.TYPES.MSG_CUSTOM) {
            return true
        }
        if (message?.type === TUIChatEngine.TYPES.MSG_CUSTOM && isCustomerServiceMessage(message) && !isMessageInvisible(message)) {
            return true
        }
        if (message?.type === TUIChatEngine.TYPES.MSG_CUSTOM && isCustomerServiceMessage(message) && isMessageInvisible(message)) {
            return false
        }
        if (message?.type === TUIChatEngine.TYPES.MSG_CUSTOM && !isCustomerServiceMessage(message)) {
            return true
        }
    } else {
        return false;
    }
    return false;

}
